==> 0.1.0-rc.1.tar.gz: lib/src/room_service/config/sdk_config.dart <==
// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.

part of room_service;

/// 'focusSwitchInterval' [int] 切换焦点视频的间隔（单位：s）
/// 'videoStreamCount' [int] 订阅视频流个数 (deviceType相关)未单独设置返回默认值
/// 'galleryPageSize' [int] 画廊单页显示数量 (clientType相关)
class SDKConfig {
  ///android version修改对应packages/meeting_sdk_android/gradle.properties的内容
  ///iOS version修改packages/meeting_sdk_ios/NEMeetingScript/spec/NEMeetingSDK.podspec的内容
  static const String sdkVersion = '2.0.0';
  static const String sdkType = 'official';
  static bool _initialized = false;

  static set initialized(bool value) {
    _initialized = value;
  }

  static bool get initialized => _initialized;

  SDKConfig._();

  static final StreamController<bool> _initNotify = StreamController.broadcast();

  static Stream<bool> get initNotifyStream => _initNotify.stream;

  static SDKConfig instance = SDKConfig._();

  static void reFetch({bool forceUpdate = false}) {
    if (forceUpdate) {
      _initialized = false;
    }
    initialize();
  }

  static Future<bool> initialize() async {
    Alog.i(
        tag: _tag,
        moduleName: _moduleName,
        content: 'initialize: $sdkVersion $sdkType');
    if (!_initialized && TextUtils.isNotEmpty(_AuthManager().appKey)) {
      var packageInfo = await PackageInfo.fromPlatform();
      var packageName = packageInfo.packageName;
      var sdkGlobalConfig = await HttpApiHelper._getSDKGlobalConfig(packageName);
      if (sdkGlobalConfig.code == RoomErrorCode.success) {
        var globalConfig = sdkGlobalConfig.data;
        instance.configs.clear();
        instance.configs.addAll(globalConfig!.configs);
        _initialized = true;
        _initNotify.add(true);

        ///美颜证书放入缓存中
        await SettingsRepository.getBeautyLicenseApi();
        Alog.d(
            tag: _tag,
            moduleName: _moduleName,
            content: 'SDKConfig initialize success');
      } else {
        Alog.d(
            tag: _tag,
            moduleName: _moduleName,
            content: 'SDKConfig initialize failed');
      }
    }
    return _initialized;
  }

  Map configs = {};

  /// 切换焦点视频的间隔（单位：s）
  static int get focusSwitchInterval => (instance.configs['focusSwitchInterval'] ?? 5) as int;

  /// 订阅视频流个数 (deviceType相关
  static int get videoStreamCount => (instance.configs['videoStreamCount'] ?? 0) as int;

  /// 画廊单页显示数量 (clientType相关)
  static int get galleryPageSize => (instance.configs['galleryPageSize'] ?? 4) as int;

  /// 会议音频录制开启，true：开启，false：关闭，true由服务器抄送给应用的回调接口
  static bool get meetingRecordAudioEnable => (instance.configs['meetingRecordAudioEnable'] ?? false) as bool;

  /// 会议视频录制开启，true：开启，false：关闭，true由服务器抄送给应用的回调接口
  static bool get meetingRecordVideoEnable => (instance.configs['meetingRecordVideoEnable'] ?? false) as bool;

  /// 会议录制模式，0：混合与单人，1：混合，2：单人，但只在有值的时候，才会由服务器抄送给应用的回调接口
  static int get meetingRecordMode => (instance.configs['meetingRecordMode'] ?? 0) as int;

  /// 美颜参数配置：证书，开关状态
  static BeautyGlobalConfig get beauty =>
      BeautyGlobalConfig.fromJson(_functionConfig('beauty'));

  /// 美颜参数配置：证书，开关状态
  static MeetingLiveConfig get live =>
      MeetingLiveConfig.fromJson(_functionConfig('meetingLive'));

  /// 白板开关状态
  static MeetingWhiteBoardConfig get whiteboard =>
      MeetingWhiteBoardConfig.fromJson(_functionConfig('whiteboard'));

  /// 会议录制开关状态
  static MeetingRecordConfig get meetingRecord =>
      MeetingRecordConfig.fromJson(_functionConfig('meetingRecord'));

  /// 会议聊天室开关状态
  static MeetingChatConfig get meetingChat =>
      MeetingChatConfig.fromJson(_functionConfig('meetingChat'));

  static Map<String,dynamic> _functionConfig(String function) {
    var config = instance.configs['functionConfigs'] ?? {};
    return (config[function] ?? <String, dynamic>{}) as Map<String, dynamic>;
  }
}

/// 全局配置
/// 'deviceConfig'[Object] 返回与客户端类型与设备型号相匹配的参数配置，若clientType未匹配则不返回
class _SDKGlobalConfig {
  Map configs = {};

  static _SDKGlobalConfig? fromJson(Map? map) {
    if (map == null) {
      return null;
    }
    var info = _SDKGlobalConfig();
    var deviceConfig = (map.remove('deviceConfig') ?? {}) as Map;
    info.configs.addAll(map);
    info.configs.addAll(deviceConfig);
    return info;
  }
}

class BaseConfig {
  late bool enable;

  BaseConfig.fromJson(Map<String, dynamic>? json) {
    enable = json != null ? json['enable'] == true : false;
  }

  Map<String, dynamic> toJson() => {'enable': enable};
}

abstract class FunBaseConfig {
  int? _status;
  int? expireAt;

  BaseConfig? config;

  @mustCallSuper
  FunBaseConfig.fromJson(Map<String, dynamic> json) {
    _status = json['status'] as int?;
    expireAt = json['expireAt'] as int?;
    config = fromJson(json['config'] as Map<String, dynamic>?);
  }

  int get status => _status ?? 0;

  BaseConfig fromJson(Map<String, dynamic>? config);

  Map<String, dynamic> toJson() =>
      {'status': _status, 'expireAt': expireAt, if (config != null) 'config': config!.toJson()};
}

class BeautyGlobalConfig extends FunBaseConfig {
  BeautyGlobalConfig.fromJson(Map<String, dynamic> json) : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BeautyConfig.fromJson(config);
  }
}

class BeautyConfig extends BaseConfig {
  String? licenseUrl;
  String? md5;

  BeautyConfig.fromJson(Map<String, dynamic>? json) : super.fromJson(json) {
    if (json != null) {
      licenseUrl = json['licenseUrl'] as String;
      md5 = json['md5'] as String;
    }
  }

  @override
  Map<String, dynamic> toJson() => {'licenseUrl': licenseUrl, 'md5': md5, ...super.toJson()};
}

class MeetingLiveConfig extends FunBaseConfig {
  MeetingLiveConfig.fromJson(Map<String, dynamic> json) : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

class MeetingWhiteBoardConfig extends FunBaseConfig {
  MeetingWhiteBoardConfig.fromJson(Map<String, dynamic> json)
      : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

class MeetingRecordConfig extends FunBaseConfig {
  MeetingRecordConfig.fromJson(Map<String, dynamic> json)
      : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

class MeetingChatConfig extends FunBaseConfig {
  MeetingChatConfig.fromJson(Map<String, dynamic> json)
      : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

==> 0.1.1-rc.0.tar.gz: lib/src/room_service/config/sdk_config.dart <==
// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.

part of room_service;

/// 'focusSwitchInterval' [int] 切换焦点视频的间隔（单位：s）
/// 'videoStreamCount' [int] 订阅视频流个数 (deviceType相关)未单独设置返回默认值
/// 'galleryPageSize' [int] 画廊单页显示数量 (clientType相关)
class SDKConfig {
  ///android version修改对应packages/meeting_sdk_android/gradle.properties的内容
  ///iOS version修改packages/meeting_sdk_ios/NEMeetingScript/spec/NEMeetingSDK.podspec的内容
  static const String sdkVersion = '2.0.0';
  static const String sdkType = 'official'; //pub
  static bool _initialized = false;

  static set initialized(bool value) {
    _initialized = value;
  }

  static bool get initialized => _initialized;

  SDKConfig._();

  static final StreamController<bool> _initNotify = StreamController.broadcast();

  static Stream<bool> get initNotifyStream => _initNotify.stream;

  static SDKConfig instance = SDKConfig._();

  static void reFetch({bool forceUpdate = false}) {
    if (forceUpdate) {
      _initialized = false;
    }
    initialize();
  }

  static Future<bool> initialize() async {
    Alog.i(
        tag: _tag,
        moduleName: _moduleName,
        content: 'initialize: version=$sdkVersion type=$sdkType');
    if (!_initialized && TextUtils.isNotEmpty(_AuthManager().appKey)) {
      var packageInfo = await PackageInfo.fromPlatform();
      var packageName = packageInfo.packageName;
      var sdkGlobalConfig = await HttpApiHelper._getSDKGlobalConfig(packageName);
      if (sdkGlobalConfig.code == RoomErrorCode.success) {
        var globalConfig = sdkGlobalConfig.data;
        instance.configs.clear();
        instance.configs.addAll(globalConfig!.configs);
        _initialized = true;
        _initNotify.add(true);

        ///美颜证书放入缓存中
        await SettingsRepository.getBeautyLicenseApi();
        Alog.d(
            tag: _tag,
            moduleName: _moduleName,
            content: 'SDKConfig initialize success');
      } else {
        Alog.d(
            tag: _tag,
            moduleName: _moduleName,
            content: 'SDKConfig initialize failed');
      }
    }
    return _initialized;
  }

  Map configs = {};

  /// 切换焦点视频的间隔（单位：s）
  static int get focusSwitchInterval => (instance.configs['focusSwitchInterval'] ?? 5) as int;

  /// 订阅视频流个数 (deviceType相关
  static int get videoStreamCount => (instance.configs['videoStreamCount'] ?? 0) as int;

  /// 画廊单页显示数量 (clientType相关)
  static int get galleryPageSize => (instance.configs['galleryPageSize'] ?? 4) as int;

  /// 会议音频录制开启，true：开启，false：关闭，true由服务器抄送给应用的回调接口
  static bool get meetingRecordAudioEnable => (instance.configs['meetingRecordAudioEnable'] ?? false) as bool;

  /// 会议视频录制开启，true：开启，false：关闭，true由服务器抄送给应用的回调接口
  static bool get meetingRecordVideoEnable => (instance.configs['meetingRecordVideoEnable'] ?? false) as bool;

  /// 会议录制模式，0：混合与单人，1：混合，2：单人，但只在有值的时候，才会由服务器抄送给应用的回调接口
  static int get meetingRecordMode => (instance.configs['meetingRecordMode'] ?? 0) as int;

  /// 美颜参数配置：证书，开关状态
  static BeautyGlobalConfig get beauty =>
      BeautyGlobalConfig.fromJson(_functionConfig('beauty'));

  /// 美颜参数配置：证书，开关状态
  static MeetingLiveConfig get live =>
      MeetingLiveConfig.fromJson(_functionConfig('meetingLive'));

  /// 白板开关状态
  static MeetingWhiteBoardConfig get whiteboard =>
      MeetingWhiteBoardConfig.fromJson(_functionConfig('whiteboard'));

  /// 会议录制开关状态
  static MeetingRecordConfig get meetingRecord =>
      MeetingRecordConfig.fromJson(_functionConfig('meetingRecord'));

  /// 会议聊天室开关状态
  static MeetingChatConfig get meetingChat =>
      MeetingChatConfig.fromJson(_functionConfig('chatroom'));

  static Map<String,dynamic> _functionConfig(String function) {
    var config = instance.configs['functionConfigs'] ?? {};
    return (config[function] ?? <String, dynamic>{}) as Map<String, dynamic>;
  }
}

/// 全局配置
/// 'deviceConfig'[Object] 返回与客户端类型与设备型号相匹配的参数配置，若clientType未匹配则不返回
class _SDKGlobalConfig {
  Map configs = {};

  static _SDKGlobalConfig? fromJson(Map? map) {
    if (map == null) {
      return null;
    }
    var info = _SDKGlobalConfig();
    var deviceConfig = (map.remove('deviceConfig') ?? {}) as Map;
    info.configs.addAll(map);
    info.configs.addAll(deviceConfig);
    return info;
  }
}

class BaseConfig {
  late bool enable;

  BaseConfig.fromJson(Map<String, dynamic>? json) {
    enable = json != null ? json['enable'] == true : false;
  }

  Map<String, dynamic> toJson() => {'enable': enable};
}

abstract class FunBaseConfig {
  int? _status;
  int? expireAt;

  BaseConfig? config;

  @mustCallSuper
  FunBaseConfig.fromJson(Map<String, dynamic> json) {
    _status = json['status'] as int?;
    expireAt = json['expireAt'] as int?;
    config = fromJson(json['config'] as Map<String, dynamic>?);
  }

  int get status => _status ?? 0;

  BaseConfig fromJson(Map<String, dynamic>? config);

  Map<String, dynamic> toJson() =>
      {'status': _status, 'expireAt': expireAt, if (config != null) 'config': config!.toJson()};
}

class BeautyGlobalConfig extends FunBaseConfig {
  BeautyGlobalConfig.fromJson(Map<String, dynamic> json) : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BeautyConfig.fromJson(config);
  }
}

class BeautyConfig extends BaseConfig {
  String? licenseUrl;
  String? md5;

  BeautyConfig.fromJson(Map<String, dynamic>? json) : super.fromJson(json) {
    if (json != null) {
      licenseUrl = json['licenseUrl'] as String;
      md5 = json['md5'] as String;
    }
  }

  @override
  Map<String, dynamic> toJson() => {'licenseUrl': licenseUrl, 'md5': md5, ...super.toJson()};
}

class MeetingLiveConfig extends FunBaseConfig {
  MeetingLiveConfig.fromJson(Map<String, dynamic> json) : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

class MeetingWhiteBoardConfig extends FunBaseConfig {
  MeetingWhiteBoardConfig.fromJson(Map<String, dynamic> json)
      : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

class MeetingRecordConfig extends FunBaseConfig {
  MeetingRecordConfig.fromJson(Map<String, dynamic> json)
      : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}

class MeetingChatConfig extends FunBaseConfig {
  MeetingChatConfig.fromJson(Map<String, dynamic> json)
      : super.fromJson(json);

  @override
  BaseConfig fromJson(Map<String, dynamic>? config) {
    return BaseConfig.fromJson(config);
  }
}
